@@ -1,5 +1,8 @@
 from twisted.internet import defer, task
 
+class IntervalTooShortError(Exception):
+    pass
+
 class _ConcurrencyPrimitive(object):
     _execute = defer.maybeDeferred
 
@@ -84,6 +87,9 @@ class ThrottlingDeferred(_ConcurrencyPrimitive):
         """
         _ConcurrencyPrimitive.__init__(self)
 
+        if interval < .1:
+            raise IntervalTooShortError("Can't set interval less than .1. Raise the number of calls")
+
         self._sem = defer.DeferredSemaphore(concurrency)
         self._execute = self._sem.run
 
